<?php
/*
Plugin Name: CadreWorks Feedzilla Client
Plugin URI: http://cadreworks.com/api/plugins
Description: A Feedzilla (http://feezilla.com) client.
Author: CadreWorks Pty Ltd
Version: 1.5
Author URI: http://cadreworks.com
*/

function cw_feedzilla_submit() {
  echo "Called cw_feedzilla_submit";
}

add_action('admin_menu', 'cw_feedzilla_plugin_menu');
add_action('wp_enqueue_scripts', 'cw_feedzilla_scripts');

//AJAX actions
add_action('wp_ajax_cw_feedzilla_refresh', 'cw_feedzilla_refresh_callback');
add_action('wp_ajax_nopriv_cw_feedzilla_refresh', 'cw_feedzilla_refresh_callback');
add_action('wp_ajax_cw_feedzilla_cultures', 'cw_feedzilla_cultures_callback');
add_action('wp_ajax_nopriv_cw_feedzilla_cultures', 'cw_feedzilla_cultures_callback');
add_action('wp_ajax_cw_feedzilla_categories', 'cw_feedzilla_categories_callback');
add_action('wp_ajax_nopriv_cw_feedzilla_categories', 'cw_feedzilla_categories_callback');
add_action('wp_ajax_cw_feedzilla_subcategories', 'cw_feedzilla_subcategories_callback');
add_action('wp_ajax_nopriv_cw_feedzilla_subcategories', 'cw_feedzilla_subcategories_callback');

add_action( 'wp_enqueue_script', 'load_jquery' );

add_shortcode('cw_feedzilla_newsfeed', 'cw_feedzilla_newsfeed_handler');

function cw_feedzilla_plugin_menu() {
	add_options_page( 'CadreWorks Feedzilla Options', 'CadreWorks Feedzilla', 'manage_options', 'cw-feedzilla', 'cw_feedzilla_plugin_options' );
}

function cw_feedzilla_plugin_options() {
  if ( !current_user_can( 'manage_options' ) )  {
    wp_die( __( 'You do not have sufficient permissions to access this page.' ) );
  }
  $hidden_field_name = 'cw_feedzilla_submit';
  $api_url_field_name = 'cw_feedzilla_api_url';
  $headline_count_field_name = 'cw_feedzilla_headline_count';
  $title_only_field_name = 'cw_feedzilla_title_only';
  $include_images_field_name = 'cw_feedzilla_include_images';

  $api_url_opt_name = 'cw_feedzilla_api_url';
  $headline_count_opt_name = 'cw_feedzilla_headline_count';
  $title_only_opt_name = 'cw_feedzilla_title_only';
  $include_images_opt_name = 'cw_feedzilla_include_images';

    // Read in existing option value from database
  $api_url = get_option( $api_url_opt_name, 'http://api.feedzilla.com/v1' );
  $headline_count = get_option( $headline_count_opt_name, 20 );
  $title_only = get_option( $title_only_opt_name, false );
  $include_images = get_option( $include_images_opt_name, true );

  // See if the user has posted us some information
  // If they did, this hidden field will be set to 'Y'
  if( isset($_POST[ $hidden_field_name ]) && $_POST[ $hidden_field_name ] == 'Y' ) {
      // Read their posted value
      $api_url = $_POST[ $api_url_field_name ];
      $headline_count = $_POST[ $headline_count_field_name ];
      $title_only = $_POST[ $title_only_field_name ];
      $include_images = $_POST[ $include_images_field_name ];

      // Save the posted value in the database
      update_option( $api_url_opt_name, $api_url );
      update_option( $headline_count_opt_name, $headline_count );
      update_option( $title_only_opt_name, $title_only );
      update_option( $include_images_opt_name, $include_images );

      // Put an settings updated message on the screen

?>
<div class="updated"><p><strong><?php _e('Settings saved.', 'menu-cw_feedzilla' ); ?></strong></p></div>
<?php

  }

  // Now display the settings editing screen

  echo '<div class="wrap">';

  // header

  echo "<h2>" . __( 'CadreWorks Feedzilla Plugin Settings', 'cw_feedzilla' ) . "</h2>";

  // settings form
    
  ?>

<form name="form1" method="post" action="" enctype="multipart/form-data">
<input type="hidden" name="<?php echo $hidden_field_name; ?>" value="Y">
<p/>
<table>
  <tr>
    <th colspan="2">
      Connection Settings
    </th>
  </tr>
  <tr>
    <td>
      <?php _e("API URL:", 'cw_feedzilla' ); ?> 
    </td>
    <td>
      <input type="text" name="<?php echo $api_url_field_name; ?>" value="<?php echo $api_url; ?>" size="20">
    </td>
  </tr>
  <tr>
    <td>
      <?php _e("Headline Count:", 'cw_feedzilla' ); ?> 
    </td>
    <td>
      <input type="text" name="<?php echo $headline_count_field_name; ?>" value="<?php echo $headline_count; ?>" size="10">
    </td>
  </tr>
  <tr>
    <td>
      <?php _e("Titles Only:", 'cw_feedzilla' ); ?> 
    </td>
    <td>
      <input type="checkbox" name="<?php echo $title_only_field_name; ?>" <?php if ($title_only) { ?>checked<?php } ?>/>
    </td>
  </tr>
  <tr>
    <td>
      <?php _e("Include Images:", 'cw_feedzilla' ); ?> 
    </td>
    <td>
      <input type="checkbox" name="<?php echo $include_images_field_name; ?>" <?php if ($include_images) { ?>checked<?php } ?>/>
    </td>
  </tr>
</table>
</p>
<hr />

<p class="submit">
<input id="submit" type="submit" name="Submit" class="button-primary" value="<?php esc_attr_e('Save Changes') ?>" />
</p>

</form>
</div>

<?php

}

function cw_feedzilla_scripts() {
  wp_register_style('cw_feedzilla_styles', plugins_url('/css/cw-feedzilla.css', __FILE__));
  wp_enqueue_style('cw_feedzilla_styles');
  wp_enqueue_script('cw_feedzilla_ajax_script', plugins_url('/js/cw-feedzilla.js', __FILE__));
  wp_localize_script('cw_feedzilla_ajax_script', 'ajax_object', array( 'ajax_url' => admin_url('admin-ajax.php'), 'we_value' => 1234));
}

function cw_feedzilla_cultures_callback () {
  //Refresh the news listing
  $api_url_opt_name = 'cw_feedzilla_api_url';

    // Read in existing option value from database
  $api_url = get_option( $api_url_opt_name, 'http://api.feedzilla.com/v1' );
  $message = wp_remote_get($api_url . '/cultures.json');
  $cultures = json_decode($message['body']);
  $html = "";
  foreach ($cultures as $culture) {
    $html .= "<option value=\"$culture->culture_code\">$culture->display_culture_name</option>";
  }
  echo $html;
  die();
}

function cw_feedzilla_categories_callback () {
  $culture_code = $_POST['culture_code'];
  //Refresh the news listing
  $api_url_opt_name = 'cw_feedzilla_api_url';

    // Read in existing option value from database
  $api_url = get_option( $api_url_opt_name, 'http://api.feedzilla.com/v1' );
  $message = wp_remote_get($api_url . "/categories.json?culture_code=$culture_code");
  $categories = json_decode($message['body']);
  $html = "";
  foreach ($categories as $category) {
    $html .= "<option value=\"$category->category_id\">$category->display_category_name</option>";
  }
  echo $html;
  die();
}

function cw_feedzilla_subcategories_callback () {
  $category_code = $_POST['category_code'];
  //Refresh the news listing
  $api_url_opt_name = 'cw_feedzilla_api_url';

    // Read in existing option value from database
  $api_url = get_option( $api_url_opt_name, 'http://api.feedzilla.com/v1' );
  $message = wp_remote_get($api_url . "/categories/$category_code/subcategories.json");
  $subcategories = json_decode($message['body']);
  $html = "";
  foreach ($subcategories as $subcategory) {
    $html .= "<option value=\"$subcategory->subcategory_id\">$subcategory->display_subcategory_name</option>";
  }
  echo $html;
  die();
}

function cw_feedzilla_refresh_callback () {
  $category_code = $_POST['category_code'];
  $subcategory_code = $_POST['subcategory_code'];
  $search_term = $_POST['search_term'];
  $order = $_POST['order'];

  //Refresh the news listing
  $api_url_opt_name = 'cw_feedzilla_api_url';
  $headline_count_opt_name = 'cw_feedzilla_headline_count';
  $title_only_opt_name = 'cw_feedzilla_title_only';
  $include_images_opt_name = 'cw_feedzilla_include_images';

    // Read in existing option value from database
  $api_url = get_option( $api_url_opt_name, 'http://api.feedzilla.com/v1' );
  $headline_count = get_option( $headline_count_opt_name, '20' );
  $title_only = get_option( $title_only_opt_name, '0' );
  $include_images = get_option( $include_images_opt_name, true );

  if (!isset($search_term) || $search_term == null || $search_term == '') {
    $message = wp_remote_get($api_url . "/categories/$category_code/subcategories/$subcategory_code/articles.json?count=$headline_count&title_only=$title_only&order=$order");
  } else {
    $message = wp_remote_get($api_url . "/categories/$category_code/subcategories/$subcategory_code/articles/search.json?q=$search_term&count=$headline_count&title_only=$title_only&order=$order");
  }

  $articles = json_decode($message['body']);
  $html = "";
  foreach ($articles as $article) {
    foreach ($article as $article_item) {
      $html .= '<div class="cw_feedzilla_article">';
      $html .= '  <div class="cw_feedzilla_headline"><a href="';
      $html .= $article_item->url;
      $html .= '">';
      $html .= $article_item->title;
      $html .= '</a>';
      $html .= '  </div>';
      $html .= '  <div class="cw_feedzilla_publish_date">';
      $html .= $article_item->publish_date;
      $html .= '  </div>';
      $html .= '  <div class="cw_feedzilla_summary">';
      $html .= $article_item->summary;
      $html .= '&nbsp;<a href="';
      $html .= $article_item->title;
      $html .= '">More&hellip;</a>';
      $html .= '  </div>';
      if ($article_item->enclosures && sizeof($article_item->enclosures) > 0) {
        foreach ($article_item->enclosures as $enclosure) {
          if (strpos($enclosure->media_type, 'image') !== FALSE) {
            if ($include_images) {
	      $html .= '  <div class="cw_feedzilla_image">';
	      $html .= '    <img src="';
	      $html .= $enclosure->uri;
	      $html .= '"/>';
	      $html .= '  </div>';
            }
          }
        }
      }
      $html .= '</div>';
    }
  }

  if ($html == "") {
    $html = '<div class="cw_feedzilla_article"><div class="cw_feedzilla_headline">No Matching Articles Found</div></div>';
  }
  $html .= '<div id="cw_feedzilla_logo"><a href="http://www.feedzilla.com"><img src="' . plugins_url("/img/feedzilla-logo.png", __FILE__) . '"/></a></div>';
  echo $html;
  die();
}

function cw_feedzilla_newsfeed_handler ($atts, $content, $tag) {
  ?>
  <div id="cw_feedzilla_navbar">
    <div class="cw_feedzilla_navbar_title">
      Language:
    </div>
    <div class="cw_feedzilla_navbar_section">
      <select id="cw_feedzilla_cultures" class="cw_feedzilla_select">
      </select>
    </div>
    <div class="cw_feedzilla_navbar_title">
      Category:
    </div>
    <div class="cw_feedzilla_navbar_section">
      <select id="cw_feedzilla_categories" class="cw_feedzilla_select">
      </select>
    </div>
    <div class="cw_feedzilla_navbar_title">
      Sub-category:
    </div>
    <div class="cw_feedzilla_navbar_section">
      <select id="cw_feedzilla_subcategories" class="cw_feedzilla_select">
      </select>
    </div>
    <div class="cw_feedzilla_navbar_title">
      Search:
    </div>
    <div class="cw_feedzilla_navbar_section">
      <input id="cw_feedzilla_search" type="text"/>
    </div>
    <div class="cw_feedzilla_navbar_title">
      Sort by:
    </div>
    <div class="cw_feedzilla_navbar_section">
      <input id="cw_feedzilla_order_relevance" name="order" type="radio" value="relevance"/>Relevance
      <br/>
      <input id="cw_feedzilla_order_date" name="order" type="radio" value="date"/>Date
    </div>
    <input id="cw_feedzilla_refresh" type="button" value="Refresh"/>
    <span id="cw_feedzilla_loading">Loading...</span>
    <a href="http://cadreworks.com"><img id="cw_feedzilla_cw_logo" src="<?php echo plugins_url("/img/cadreworks-logo.png", __FILE__); ?>"/></a>
  </div>
  <div id="cw_feedzilla_messages"></div>
  <div id="cw_feedzilla_headline_list"></div>
<?php
}

function load_jquery() {
    wp_enqueue_script( 'jquery' );
}
